==> haskell-keys-3.12.2-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.2
id: keys-3.12.2-LcRN93kYPIkB7wExpz9vwU
key: keys-3.12.2-LcRN93kYPIkB7wExpz9vwU
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: 9560c73ca0279d857593655f1bc8dfe8
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/keys-3.12.2
hs-libraries: HSkeys-3.12.2-LcRN93kYPIkB7wExpz9vwU
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ
    containers-0.6.0.1 free-5.1.1-1K5khJIEJhD3OYmMFulomt
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.2-3AlcFqp0RiMBEG1nuNdxa4
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.2-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.2
id: keys-3.12.2-4wcuGMQYbtgGypqt6xPGOn
key: keys-3.12.2-4wcuGMQYbtgGypqt6xPGOn
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: 2e757b08b494c871bda59a597f9d0ae7
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/keys-3.12.2
hs-libraries: HSkeys-3.12.2-4wcuGMQYbtgGypqt6xPGOn
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ
    containers-0.6.0.1 free-5.1.1-Ij3ZXSHiEBQ7mGblegjtYc
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.2-K5SaVm4N6AL6wYPHZFU5px
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
